@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '1.06';
+  $CPAN::Perl::Releases::VERSION = '1.08';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -367,6 +367,10 @@ our $data =
     "tar.bz2" => "B/BI/BINGOS/perl-5.17.9.tar.bz2",
     "tar.gz" => "B/BI/BINGOS/perl-5.17.9.tar.gz",
   },
+  "5.17.10" => {
+    "tar.bz2" => "C/CO/CORION/perl-5.17.10.tar.bz2",
+    "tar.gz" => "C/CO/CORION/perl-5.17.10.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -475,7 +479,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 1.06
+version 1.08
 
 =head1 SYNOPSIS
 
